@@ -1,41 +1,32 @@
-/***************************************************************************
- *   Copyright 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "puzzlecreator.h"
 #include "slicerconfwidget.h"
 #include "file-io/components.h"
 #include "file-io/puzzle.h"
 #include "file-io/puzzlestructs.h"
-#include "../libpala/slicer.h"
-#include "../libpala/slicerjob.h"
-#include "../libpala/slicermode.h"
+
+#include <Pala/Slicer>
+#include <Pala/SlicerJob>
+#include <Pala/SlicerMode>
 
 #include <QFormLayout>
 #include <QLabel>
 #include <QStackedWidget>
 #include <QUuid>
+#include <QImageReader>
+
 #include <KLineEdit>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KUrlRequester>
 
 Palapeli::PuzzleCreatorDialog::PuzzleCreatorDialog()
-	: m_result(0)
+	: m_result(nullptr)
 	, m_imageSelector(new KUrlRequester)
 	, m_nameEdit(new KLineEdit)
 	, m_commentEdit(new KLineEdit)
@@ -48,6 +39,13 @@ Palapeli::PuzzleCreatorDialog::PuzzleCreatorDialog()
 	buttonBox()->button(QDialogButtonBox::Help)->setVisible(false);
 	//setup image selector
 	m_imageSelector->setMode(KFile::File | KFile::LocalOnly | KFile::ExistingOnly);
+	const auto supportedImageTypes = QImageReader::supportedMimeTypes();
+	QStringList mimeTypeFilters;
+	mimeTypeFilters.reserve(supportedImageTypes.size());
+	for (const auto& imageType : supportedImageTypes) {
+	    mimeTypeFilters.append(QString::fromUtf8(imageType));
+	}
+	m_imageSelector->setMimeTypeFilters(mimeTypeFilters);
 	//build sublayouts
 	QFormLayout* sourceLayout = new QFormLayout;
 	sourceLayout->addRow(i18nc("@label:chooser", "Image file:"), m_imageSelector);
@@ -55,7 +53,8 @@ Palapeli::PuzzleCreatorDialog::PuzzleCreatorDialog()
 	sourceLayout->addRow(i18nc("@label:textbox", "Image name:"), m_nameEdit);
 	sourceLayout->addRow(i18nc("@label:textbox (like in: This comment is optional.)", "Optional comment:"), m_commentEdit);
 	sourceLayout->addRow(i18nc("@label:textbox", "Name of image author:"), m_authorEdit);
-	foreach (const Pala::Slicer* slicer, m_slicerSelector->slicers())
+        const auto slicers = m_slicerSelector->slicers();
+	for (const Pala::Slicer* slicer : slicers)
 	{
 		m_slicerConfigWidgets[slicer] = new Palapeli::SlicerConfigWidget(slicer);
 		m_slicerConfigMasterWidget->addWidget(m_slicerConfigWidgets[slicer]);
